@@ -5,7 +5,7 @@
 # datetime:2021-06-10 16:45
 # software: PyCharm
 import requests
-from setting import SURVEILLANCE_SYSTEM_DOMAIN, SURVEILLANCE_SYSTEM_TOKEN
+from protocol_helper.setting import SURVEILLANCE_SYSTEM_DOMAIN, SURVEILLANCE_SYSTEM_TOKEN
 
 
 class MonitoringCenterService(object):
